@@ -11,10 +11,7 @@ use strict;
 use warnings;
 use autodie;
 
-use parent (
-    'TestHTTPCpanelMixin',
-    'Test::Class',
-);
+use parent 'Test::Class';
 
 use Test::More;
 use Test::Deep;
